"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createDuck = createDuck;
function createDuck(name, app) {
  function defineType(type) {
    if (app) {
      return app + "/" + name + "/" + type;
    }
    return name + "/" + type;
  }

  function createReducer(cases) {
    var defaultState = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

    return function reducer() {
      var state = arguments.length <= 0 || arguments[0] === undefined ? defaultState : arguments[0];
      var action = arguments.length <= 1 || arguments[1] === undefined ? {} : arguments[1];

      if (state === undefined) return defaultState;
      for (var caseName in cases) {
        if (action.type === caseName) return cases[caseName](state, action);
      }
      return state;
    };
  }

  function createAction(type) {
    return function actionCreator(payload) {
      var action = {
        type: type
      };

      if (payload) action.payload = payload;

      return action;
    };
  }

  return {
    defineType: defineType,
    createReducer: createReducer,
    createAction: createAction
  };
}